@@ -7,7 +7,7 @@ class Setup:
     INIT_SCRIPT_PATH = 'jal_init.sql'
     UPDATES_PATH = 'updates'
     UPDATE_PREFIX = 'jal_delta_'
-    TARGET_SCHEMA = 22
+    TARGET_SCHEMA = 25
     CALC_TOLERANCE = 1e-10
     DISP_TOLERANCE = 1e-4
 
@@ -84,6 +84,7 @@ class PredefinedAsset:
     ETF = 4
     Commodity = 5
     Derivative = 6
+    Forex = 7
 
 
 class PredefinedPeer:
@@ -96,6 +97,7 @@ class MarketDataFeed:
     RU = 1
     US = 2
     EU = 3
+    CA = 4
 
 
 class CustomColor:
