@@ -4,7 +4,8 @@ from datetime import datetime, timezone
 from itertools import groupby
 from lxml import etree
 
-from jal.constants import TransactionType, PredefinedAsset, PredefinedCategory, CorporateAction, DividendSubtype
+from jal.constants import TransactionType, PredefinedAsset, PredefinedCategory, CorporateAction, DividendSubtype, \
+    MarketDataFeed
 from jal.widgets.helpers import g_tr, ManipulateDate
 from jal.db.update import JalDB
 from jal.db.helpers import executeSQL, readSQL, get_country_by_code, update_asset_country
@@ -22,13 +23,14 @@ class IBKRCashOp:
 
 # -----------------------------------------------------------------------------------------------------------------------
 class IBKR:
+    NotSupported = -1
     BondPricipal = 1000
     CancelledFlag = 'Ca'
     PaymentInLiueOfDividend = 'PAYMENT IN LIEU OF DIVIDEND'
     TaxFullPattern = r"^(?P<description>.*) - (?P<country>\w\w) TAX$"
     TaxNotePattern = r"^(?P<symbol>.*\w) ?\((?P<isin>\w+)\)(?P<prefix>( \w*)+) +(?P<amount>\d+\.\d+)?(?P<suffix>.*)$"
     DividendNotePattern = r"^(?P<symbol>.*\w) ?\((?P<isin>\w+)\)(?P<prefix>( \w*)+) +(?P<amount>\d+\.\d+)?(?P<suffix>.*) \(.*\)$"
-    MergerPattern = r"^(?P<symbol_old>\w+)\((?P<isin_old>\w+)\) +MERGED\(\w+\) +WITH +(?P<isin_new>\w+) +(?P<X>\d+) +FOR +(?P<Y>\d+) +\((?P<symbol>\w+), (?P<name>.*), (?P<id>\w+)\)$"
+    MergerPattern = r"^(?P<symbol_old>\w+)(.OLD)?\((?P<isin_old>\w+)\) +MERGED\(\w+\) +WITH +(?P<isin_new>\w+) +(?P<X>\d+) +FOR +(?P<Y>\d+) +\((?P<symbol>\w+)(.OLD)?, (?P<name>.*), (?P<id>\w+)\)$"
     SpinOffPattern = r"^(?P<symbol_old>\w+)\((?P<isin_old>\w+)\) +SPINOFF +(?P<X>\d+) +FOR +(?P<Y>\d+) +\((?P<symbol>\w+), (?P<name>.*), (?P<id>\w+)\)$"
     SymbolChangePattern = r"^(?P<symbol_old>\w+)\((?P<isin_old>\w+)\) +CUSIP\/ISIN CHANGE TO +\((?P<isin_new>\w+)\) +\((?P<symbol>\w+), (?P<name>.*), (?P<id>\w+)\)$"
     SplitPattern = r"^(?P<symbol_old>\w+)\((?P<isin_old>\w+)\) +SPLIT +(?P<X>\d+) +FOR +(?P<Y>\d+) +\((?P<symbol>\w+), (?P<name>.*), (?P<id>\w+)\)$"
@@ -38,7 +40,8 @@ class IBKR:
         'STK': PredefinedAsset.Stock,
         'BOND': PredefinedAsset.Bond,
         'OPT': PredefinedAsset.Derivative,
-        'FUT': PredefinedAsset.Derivative
+        'FUT': PredefinedAsset.Derivative,
+        'WAR': PredefinedAsset.Derivative
     }
 
     CorpAction = {
@@ -50,6 +53,15 @@ class IBKR:
         'RS': CorporateAction.Split
     }
 
+    Exchanges = {
+        'NYSE': MarketDataFeed.US,
+        'ARCA': MarketDataFeed.US,
+        'NASDAQ': MarketDataFeed.US,
+        'TSE': MarketDataFeed.CA,
+        'SBF': MarketDataFeed.EU,
+        'AMEX': MarketDataFeed.US
+    }
+
     def __init__(self, parent, filename):
         self._parent = parent
         self._filename = filename
@@ -95,11 +107,8 @@ class IBKR:
         try:
             return IBKR.AssetType[data.attrib[name]]
         except KeyError:
-            if default_value is not None:
-                return default_value
-            else:
-                logging.error(g_tr('IBKR', "Asset type isn't supported: ") + f"{data.attrib[name]}")
-                return None
+            logging.warning(g_tr('IBKR', "Asset type isn't supported: ") + f"{data.attrib[name]}")
+            return default_value
 
     @staticmethod
     def flCorpActionType(data, name, default_value):
@@ -108,11 +117,8 @@ class IBKR:
         try:
             return IBKR.CorpAction[data.attrib[name]]
         except KeyError:
-            if default_value is not None:
-                return default_value
-            else:
-                logging.error(g_tr('IBKR', "Corporate action isn't supported: ") + f"{data.attrib[name]}")
-                return None
+            logging.warning(g_tr('IBKR', "Corporate action isn't supported: ") + f"{data.attrib[name]}")
+            return default_value
 
     @staticmethod
     def flCashOpType(data, name, default_value):
@@ -227,17 +233,18 @@ class IBKR:
             'CashReport': {'tag': 'CashReportCurrency',
                            'level': 'Currency',
                            'values': [('accountId', IBKR.flAccount, None),
-                                      ('endingSettledCash', IBKR.flNumber, None)]},
+                                      ('endingCash', IBKR.flNumber, None)]},
             'SecuritiesInfo': {'tag': 'SecurityInfo',
                                'level': '',
                                'values': [('symbol', IBKR.flString, None),
-                                          ('assetCategory', IBKR.flAssetType, None),
+                                          ('assetCategory', IBKR.flAssetType, IBKR.NotSupported),
                                           ('subCategory', IBKR.flString, ''),
                                           ('description', IBKR.flString, None),
-                                          ('isin', IBKR.flString, '')]},
+                                          ('isin', IBKR.flString, ''),
+                                          ('listingExchange', IBKR.flString, '')]},
             'Trades': {'tag': 'Trade',
                        'level': 'EXECUTION',
-                       'values': [('assetCategory', IBKR.flAssetType, None),
+                       'values': [('assetCategory', IBKR.flAssetType, IBKR.NotSupported),
                                   ('symbol', IBKR.flAsset, None),
                                   ('accountId', IBKR.flAccount, None),
                                   ('dateTime', IBKR.flTimestamp, None),
@@ -264,12 +271,12 @@ class IBKR:
                                      ('notes', IBKR.flString, '')]},
             'CorporateActions': {'tag': 'CorporateAction',
                                  'level': 'DETAIL',
-                                 'values': [('type', IBKR.flCorpActionType, None),
+                                 'values': [('type', IBKR.flCorpActionType, IBKR.NotSupported),
                                             ('accountId', IBKR.flAccount, None),
                                             ('symbol', IBKR.flAsset, None),
                                             ('isin', IBKR.flString, ''),
                                             ('listingExchange', IBKR.flString, ''),
-                                            ('assetCategory', IBKR.flAssetType, None),
+                                            ('assetCategory', IBKR.flAssetType, IBKR.NotSupported),
                                             ('dateTime', IBKR.flTimestamp, None),
                                             ('transactionID', IBKR.flString, ''),
                                             ('description', IBKR.flString, None),
@@ -318,18 +325,24 @@ class IBKR:
 
     def loadIBBalances(self, balances):
         for balance in balances:
-            self._settled_cash[balance['accountId']] = balance['endingSettledCash']
+            self._settled_cash[balance['accountId']] = balance['endingCash']
 
     def loadIBSecurities(self, assets):
         cnt = 0
         for asset in assets:
+            if asset['assetCategory'] == IBKR.NotSupported:   # Skip not supported type of asset
+                continue
             # IB may use '.OLD' suffix if asset is being replaced
             symbol = asset['symbol'][:-len('.OLD')] if asset['symbol'].endswith('.OLD') else asset['symbol']
             asset_id = JalDB().get_asset_id(symbol, isin=asset['isin'], dialog_new=False)
             if asset_id is not None:
                 continue
             asset_type = PredefinedAsset.ETF if asset['subCategory'] == "ETF" else asset['assetCategory']
-            JalDB().add_asset(symbol, asset['description'], asset_type, asset['isin'])
+            try:
+                exchange = IBKR.Exchanges[asset['listingExchange']]
+            except KeyError:
+                exchange = MarketDataFeed.NA
+            JalDB().add_asset(symbol, asset['description'], asset_type, asset['isin'], data_source=exchange)
             cnt += 1
         logging.info(g_tr('StatementLoader', "Securities loaded: ") + f"{cnt} ({len(assets)})")
 
@@ -346,7 +359,7 @@ class IBKR:
             try:
                 cnt += ib_trade_loaders[trade['assetCategory']](trade)
             except KeyError:
-                logging.error(g_tr('StatementLoader', "Asset type isn't supported for trade: ") + f"{trade})")
+                logging.warning(g_tr('StatementLoader', "Asset type isn't supported for trade: ") + f"{trade})")
         logging.info(g_tr('StatementLoader', "Trades loaded: ") + f"{cnt} ({len(trades)})")
 
     def loadIBCorporateActions(self, actions):
@@ -494,7 +507,7 @@ class IBKR:
                     paired_record[0]['jal_processed'] = True
                     cnt += 2
             else:
-                logging.error(g_tr('StatementLoader', "Corporate action type is not supported: ")
+                logging.warning(g_tr('StatementLoader', "Corporate action type is not supported: ")
                               + f"{action['type']}")
                 continue
         logging.info(g_tr('StatementLoader', "Corporate actions loaded: ") + f"{cnt} ({len(actions)})")
@@ -527,7 +540,7 @@ class IBKR:
         for option in options:
             try:
                 description = transaction_desctiption[option['transactionType']]
-                if description:
+                if description:   # TODO add condition to check that update found relevant trade
                     _ = executeSQL("UPDATE trades SET note=:description WHERE "
                                    "account_id=:account_id AND asset_id=:asset_id AND number=:trade_id",
                                    [(":description", description), (":account_id", option['accountId']),
