@@ -76,11 +76,11 @@ class OperationsModel(QAbstractTableModel):
         self._amount_delegate = None
         self._data = []
         self._row_count = 0
-        self._table_name = 'all_operations'
         self._query = QSqlQuery(db_connection())
         self._begin = 0
         self._end = 0
         self._account = 0
+        self._text_filter = ''
 
         self.prepareData()
 
@@ -162,7 +162,16 @@ class OperationsModel(QAbstractTableModel):
                     return self._data[row][self.COL_ACCOUNT] + " <- " + self._data[row][self.COL_NOTE2]
         elif column == 3:
             if self._data[row][self.COL_TYPE] == TransactionType.Action:
-                return self._data[row][self.COL_NUMBER_PEER]
+                note = self._data[row][self.COL_NUMBER_PEER]
+                if self._data[row][self.COL_ASSET] != '' and self._data[row][self.COL_FEE_TAX] != 0:
+                    note += "\n" + g_tr('OperationsModel', "Rate: ")
+                    if self._data[row][self.COL_FEE_TAX] >= 1:
+                        note += f"{self._data[row][self.COL_FEE_TAX]:.4f} " \
+                                f"{self._data[row][self.COL_ASSET]}/{self._data[row][self.COL_CURRENCY]}"
+                    else:
+                        note += f"{1/self._data[row][self.COL_FEE_TAX]:.4f} " \
+                                f"{self._data[row][self.COL_CURRENCY]}/{self._data[row][self.COL_ASSET]}"
+                return note
             elif self._data[row][self.COL_TYPE] == TransactionType.Transfer:
                 rate = 0 if self._data[row][self.COL_PRICE] == '' else self._data[row][self.COL_PRICE]
                 if self._data[row][self.COL_CURRENCY] != self._data[row][self.COL_NUMBER_PEER]:
@@ -205,7 +214,12 @@ class OperationsModel(QAbstractTableModel):
                 return [self._data[row][self.COL_AMOUNT], self._data[row][self.COL_QTY]]
             elif self._data[row][self.COL_TYPE] == TransactionType.Dividend:
                 return [self._data[row][self.COL_AMOUNT], -self._data[row][self.COL_FEE_TAX]]
-            elif self._data[row][self.COL_TYPE] == TransactionType.Action or self._data[row][self.COL_TYPE] == TransactionType.Transfer:
+            elif self._data[row][self.COL_TYPE] == TransactionType.Action:
+                if self._data[row][self.COL_ASSET] != '':
+                    return [self._data[row][self.COL_AMOUNT], self._data[row][self.COL_PRICE]]
+                else:
+                    return [self._data[row][self.COL_AMOUNT]]
+            elif self._data[row][self.COL_TYPE] == TransactionType.Transfer:
                 return [self._data[row][self.COL_AMOUNT]]
             elif self._data[row][self.COL_TYPE] == TransactionType.CorporateAction:
                 if self._data[row][self.COL_SUBTYPE] == CorporateAction.SpinOff or self._data[row][self.COL_SUBTYPE] == CorporateAction.StockDividend:
@@ -285,7 +299,15 @@ class OperationsModel(QAbstractTableModel):
 
     @Slot()
     def filterText(self, filter):
-        pass  # TODO add free text search
+        if filter:
+            self._text_filter = f" AND (num_peer LIKE '%{filter}%' COLLATE NOCASE "\
+                                f"OR note LIKE '%{filter}%' COLLATE NOCASE "\
+                                f"OR note2 LIKE '%{filter}%' COLLATE NOCASE "\
+                                f"OR asset LIKE '%{filter}%' COLLATE NOCASE "\
+                                f"OR asset_name LIKE '%{filter}%' COLLATE NOCASE)"
+        else:
+            self._text_filter = ''
+        self.prepareData()
 
     def update(self):
         self.prepareData()
@@ -318,7 +340,8 @@ class OperationsModel(QAbstractTableModel):
         else:
             count_pfx = "SELECT COUNT(*) "
             query_pfx = "SELECT * "
-            query_suffix = f"FROM {self._table_name} AS o WHERE o.timestamp>={self._begin} AND o.timestamp<={self._end}"
+            query_suffix = f"FROM all_operations AS o WHERE o.timestamp>={self._begin} AND o.timestamp<={self._end}" + \
+                           self._text_filter
             if self._account:
                 query_suffix = query_suffix + f" AND o.account_id = {self._account}"
             self._row_count = readSQL(count_pfx + query_suffix)
