@@ -15,15 +15,16 @@ class JalSettings:
             logging.fatal("DB connection is not open")
             return
 
-    def getValue(self, key):
+    def getValue(self, key, default=None):
         get_query = QSqlQuery(self.db)
         get_query.setForwardOnly(True)
         get_query.prepare("SELECT value FROM settings WHERE name=:key")
 
-        value = None
+        value = default
         get_query.bindValue(":key", key)
         if not get_query.exec_():
-            logging.fatal(f"Failed to get settings for key='{key}'")
+            if not default:
+                logging.fatal(f"Failed to get settings for key='{key}'")
             return value
         if get_query.next():
             value = get_query.value(0)
