@@ -58,9 +58,18 @@ class JalDB():
     def commit(self):
         db_connection().commit()
 
+    def get_language_id(self, language_code):
+        return readSQL("SELECT id FROM languages WHERE language = :language_code", [(':language_code', language_code)])
+
+    def get_language_code(self, language_id):
+        return readSQL("SELECT language FROM languages WHERE id = :language_id", [(':language_id', language_id)])
+
     def get_asset_name(self, asset_id):
         return readSQL("SELECT name FROM assets WHERE id=:asset_id", [(":asset_id", asset_id)])
 
+    def get_account_name(self, account_id):
+        return readSQL("SELECT name FROM accounts WHERE id=:account_id", [(":account_id", account_id)])
+
     # Searches for account_id by account number and optional currency
     # Returns: account_id or None if no account was found
     def get_account_id(self, accountNumber, accountCurrency=''):
@@ -91,14 +100,14 @@ class JalDB():
         if isin:
             asset_id = readSQL("SELECT id FROM assets WHERE isin=:isin", [(":isin", isin)])
             if asset_id is None:
-                asset_id = readSQL("SELECT id FROM assets WHERE name=:symbol AND coalesce(isin, '')=''",
+                asset_id = readSQL("SELECT id FROM assets WHERE name=:symbol COLLATE NOCASE AND coalesce(isin, '')=''",
                                    [(":symbol", symbol)])
         else:
             if reg_code:
                 asset_id = readSQL("SELECT asset_id FROM asset_reg_id WHERE reg_code=:reg_code",
                                    [(":reg_code", reg_code)])
             if asset_id is None:
-                asset_id = readSQL("SELECT id FROM assets WHERE name=:symbol", [(":symbol", symbol)])
+                asset_id = readSQL("SELECT id FROM assets WHERE name=:symbol COLLATE NOCASE", [(":symbol", symbol)])
         if asset_id is not None:
             self.update_asset_data(asset_id, symbol, isin, reg_code)
         elif dialog_new:
@@ -119,7 +128,7 @@ class JalDB():
     def update_asset_data(self, asset_id, new_symbol='', new_isin='', new_reg=''):
         if new_symbol:
             symbol = readSQL("SELECT name FROM assets WHERE id=:asset_id", [(":asset_id", asset_id)])
-            if new_symbol != symbol:
+            if new_symbol.upper() != symbol.upper():
                 _ = executeSQL("UPDATE assets SET name=:symbol WHERE id=:asset_id",
                                [(":symbol", new_symbol), (":asset_id", asset_id)])
                 # Show warning only if symbol was changed not due known bankruptcy or new issue pattern
@@ -253,7 +262,7 @@ class JalDB():
                            "VALUES (:timestamp, :account_id, :bank_id)",
                            [(":timestamp", timestamp), (":account_id", account_id), (":bank_id", broker_id)])
         pid = query.lastInsertId()
-        _ = executeSQL("INSERT INTO action_details (pid, category_id, sum, note) "
-                       "VALUES (:pid, :category_id, :sum, :note)",
-                       [(":pid", pid), (":category_id", category_id), (":sum", amount),
+        _ = executeSQL("INSERT INTO action_details (pid, category_id, amount, note) "
+                       "VALUES (:pid, :category_id, :amount, :note)",
+                       [(":pid", pid), (":category_id", category_id), (":amount", amount),
                         (":note", description)], commit=True)
