@@ -13,7 +13,8 @@ from jal.widgets.reference_dialogs import AccountTypeListDialog, AccountListDial
     CategoryListDialog, CountryListDialog, QuotesListDialog, PeerListDialog
 from jal.constants import TransactionType
 from jal.db.backup_restore import JalBackup
-from jal.db.helpers import get_dbfilename, executeSQL
+from jal.db.helpers import get_dbfilename
+from jal.db.update import JalDB
 from jal.db.settings import JalSettings
 from jal.data_import.downloader import QuoteDownloader
 from jal.db.ledger import Ledger
@@ -77,7 +78,6 @@ class MainWindow(QMainWindow, Ui_JAL_MainWindow):
 
         # Setup reports tab
         self.reports = Reports(self.ReportTableView, self.ReportTreeView)
-        self.reports.report_failure.connect(self.onReportFailure)
 
         # Customize UI configuration
         self.balances_model = BalancesModel(self.BalancesTableView)
@@ -146,7 +146,7 @@ class MainWindow(QMainWindow, Ui_JAL_MainWindow):
         self.ShowInactiveCheckBox.stateChanged.connect(self.BalancesTableView.model().toggleActive)
         self.DateRangeCombo.currentIndexChanged.connect(self.OnOperationsRangeChange)
         self.ChooseAccountBtn.changed.connect(self.OperationsTableView.model().setAccount)
-        self.SearchString.textChanged.connect(self.OperationsTableView.model().filterText)
+        self.SearchString.editingFinished.connect(self.updateOperationsFilter)
         self.HoldingsTableView.customContextMenuRequested.connect(self.onHoldingsContextMenu)
         self.OperationsTableView.selectionModel().selectionChanged.connect(self.OnOperationChange)
         self.OperationsTableView.customContextMenuRequested.connect(self.onOperationContextMenu)
@@ -183,9 +183,7 @@ class MainWindow(QMainWindow, Ui_JAL_MainWindow):
     def onLanguageChanged(self, action):
         language_code = action.data()
         if language_code != self.currentLanguage:
-            executeSQL("UPDATE settings "
-                       "SET value=(SELECT id FROM languages WHERE language = :new_language) WHERE name ='Language'",
-                       [(':new_language', language_code)])
+            JalSettings().setValue('Language', JalDB().get_language_id(language_code))
             QMessageBox().information(self, g_tr('MainWindow', "Restart required"),
                                       g_tr('MainWindow', "Language was changed to ") +
                                       QLocale.languageToString(QLocale(language_code).language()) + "\n" +
@@ -254,10 +252,6 @@ class MainWindow(QMainWindow, Ui_JAL_MainWindow):
         else:
             self.reports.runReport(report_type, begin, end, self.ReportAccountBtn.account_id, group_dates)
 
-    @Slot()
-    def onReportFailure(self, error_msg):
-        self.StatusBar.showMessage(error_msg, timeout=30000)
-
     @Slot()
     def OnOperationsRangeChange(self, range_index):
         view_ranges = {
@@ -361,6 +355,10 @@ class MainWindow(QMainWindow, Ui_JAL_MainWindow):
         self.checkForUncommittedChanges()
         self.OperationsTabs.widget(operation_type).copyNew()
 
+    @Slot()
+    def updateOperationsFilter(self):
+        self.OperationsTableView.model().filterText(self.SearchString.text())
+
     @Slot()
     def onDataDialog(self, dlg_type):
         if dlg_type == "account_types":
